@@ -18,7 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-require_relative 'binary_string'
+require_relative 'buffer'
 require_relative 'generic'
 
 module Async
@@ -37,8 +37,11 @@ module Async
 				
 				@block_size = block_size
 				
-				@read_buffer = BinaryString.new
-				@write_buffer = BinaryString.new
+				@read_buffer = Buffer.new
+				@write_buffer = Buffer.new
+				
+				# Used as destination buffer for underlying reads.
+				@input_buffer = Buffer.new
 			end
 			
 			attr :io
@@ -49,9 +52,17 @@ module Async
 				return '' if size == 0
 				
 				if size
-					fill_read_buffer until @eof or @read_buffer.size >= size
+					until @eof or @read_buffer.size >= size
+						# Compute the amount of data we need to read from the underlying stream:
+						read_size = size - @read_buffer.bytesize
+						
+						# Don't read less than @block_size to avoid lots of small reads:
+						fill_read_buffer(read_size > @block_size ? read_size : @block_size)
+					end
 				else
-					fill_read_buffer until @eof
+					until @eof
+						fill_read_buffer
+					end
 				end
 				
 				return consume_read_buffer(size)
@@ -68,24 +79,27 @@ module Async
 				return consume_read_buffer(size)
 			end
 			
+			alias readpartial read_partial
+			
 			# Efficiently read data from the stream until encountering pattern.
 			# @param pattern [String] The pattern to match.
 			# @return [String] The contents of the stream up until the pattern, which is consumed but not returned.
-			def read_until(pattern, offset = 0)
+			def read_until(pattern, offset = 0, chomp: true)
 				until index = @read_buffer.index(pattern, offset)
 					offset = @read_buffer.size
 					
 					return unless fill_read_buffer
 				end
 				
-				matched = @read_buffer.slice!(0, index)
-				@read_buffer.slice!(0, pattern.bytesize)
+				@read_buffer.freeze
+				matched = @read_buffer.byteslice(0, index+(chomp ? 0 : pattern.bytesize))
+				@read_buffer = @read_buffer.byteslice(index+pattern.bytesize, @read_buffer.bytesize)
 				
 				return matched
 			end
 			
 			def peek
-				until yield(@read_buffer) || @eof
+				until yield(@read_buffer) or @eof
 					fill_read_buffer
 				end
 			end
@@ -108,14 +122,14 @@ module Async
 				
 				return string.bytesize
 			end
-
+			
 			# Writes `string` to the stream and returns self.
 			def <<(string)
 				write(string)
 				
 				return self
 			end
-
+			
 			# Flushes buffered data to the stream.
 			def flush
 				unless @write_buffer.empty?
@@ -123,13 +137,11 @@ module Async
 					@write_buffer.clear
 				end
 			end
-
-			def gets(separator = $/)
-				flush
-				
-				read_until(separator)
+			
+			def gets(separator = $/, **options)
+				read_until(separator, **options)
 			end
-
+			
 			def puts(*args, separator: $/)
 				args.each do |arg|
 					@write_buffer << arg << separator
@@ -159,7 +171,7 @@ module Async
 					@io.close
 				end
 			end
-
+			
 			# Returns true if the stream is at file which means there is no more data to be read.
 			def eof?
 				fill_read_buffer if !@eof && @read_buffer.empty?
@@ -179,22 +191,19 @@ module Async
 			private
 			
 			# Fills the buffer from the underlying stream.
-			def fill_read_buffer
-				# Can we read directly into the buffer? (Ruby doesn't support append, only replace):
-				if @read_buffer.empty?
-					if @io.read(@block_size, @read_buffer)
-						return true
-					end
-				elsif chunk = @io.read(@block_size)
+			def fill_read_buffer(size = @block_size)
+				if @read_buffer.empty? and @io.read(size, @read_buffer)
+					return true
+				elsif chunk = @io.read(size, @input_buffer)
 					@read_buffer << chunk
 					return true
+				else
+					# We didn't read anything, so we must be at eof:
+					@eof = true
+					return false
 				end
-				
-				# We didn't read anything, so we must be at eof:
-				@eof = true
-				return false
 			end
-
+			
 			# Consumes at most `size` bytes from the buffer.
 			# @param size [Integer|nil] The amount of data to consume. If nil, consume entire buffer.
 			def consume_read_buffer(size = nil)
@@ -203,13 +212,20 @@ module Async
 				
 				result = nil
 				
-				if size == nil || size >= @read_buffer.size
+				if size.nil? or size >= @read_buffer.size
 					# Consume the entire read buffer:
-					result = @read_buffer.dup
-					@read_buffer.clear
+					result = @read_buffer
+					@read_buffer = Buffer.new
 				else
-					# Consume only part of the read buffer:
-					result = @read_buffer.slice!(0, size)
+					# This approach uses more memory.
+					# result = @read_buffer.slice!(0, size)
+					
+					# We know that we are not going to reuse the original buffer.
+					# But byteslice will generate a hidden copy. So let's freeze it first:
+					@read_buffer.freeze
+					
+					result = @read_buffer.byteslice(0, size)
+					@read_buffer = @read_buffer.byteslice(size, @read_buffer.bytesize)
 				end
 				
 				return result
