@@ -20,8 +20,12 @@
 
 require 'async/io/unix_socket'
 
-RSpec.describe Async::Reactor do
-	include_context Async::RSpec::Leaks
+require_relative 'generic_examples'
+
+RSpec.describe Async::IO::UNIXSocket do
+	include_context Async::RSpec::Reactor
+	
+	it_should_behave_like Async::IO::Generic
 	
 	let(:path) {File.join(__dir__, "unix-socket")}
 	let(:data) {"The quick brown fox jumped over the lazy dog."}
@@ -34,26 +38,27 @@ RSpec.describe Async::Reactor do
 		FileUtils.rm_f path
 	end
 	
-	describe 'basic unix socket' do
-		it "should echo data back to peer" do
-			subject.async do
-				Async::IO::UNIXServer.wrap(path) do |server|
-					server.accept do |peer|
-						peer.send(peer.recv(512))
-					end
+	it "should echo data back to peer" do
+		reactor.async do
+			Async::IO::UNIXServer.wrap(path) do |server|
+				server.accept do |peer|
+					peer.send(peer.recv(512))
 				end
 			end
-			
-			subject.async do
-				Async::IO::UNIXSocket.wrap(path) do |client|
-					client.send(data)
-					response = client.recv(512)
+		end
+		
+		reactor.async do
+			Async::IO::UNIXSocket.wrap(path) do |client|
+				client.send(data)
 				
-					expect(response).to be == data
-				end
+				response = client.recv(512)
+				
+				expect(response).to be == data
 			end
-			
-			subject.run
 		end
 	end
 end
+
+RSpec.describe Async::IO::UNIXServer do
+	it_should_behave_like Async::IO::Generic
+end
